Extensions for django-pages-cms application
===========================================

``django-pages-cms-extensions`` is a extensions for django-pages-cms application

.. image:: https://travis-ci.org/dlancer/django-pages-cms-extensions.svg?branch=master
    :target: https://travis-ci.org/dlancer/django-pages-cms-extensions/
    :alt: Build status

.. image:: https://img.shields.io/pypi/v/django-pages-cms-extensions.svg
    :target: https://pypi.python.org/pypi/django-pages-cms-extensions/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-pages-cms-extensions.svg
    :target: https://pypi.python.org/pypi/django-pages-cms-extensions/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/format/django-pages-cms-extensions.svg
    :target: https://pypi.python.org/pypi/django-pages-cms-extensions/
    :alt: Download format

.. image:: https://img.shields.io/pypi/l/django-pages-cms-extensions.svg
    :target: https://pypi.python.org/pypi/django-pages-cms-extensions/
    :alt: License

Requirements
------------

::

    django-pages-cms>=0.2.0
    django-image-cropping>=1.0.3
    django-taggit>=0.18.0
    django-embed-video>=1.1.0
    easy_thumbnails>=2.3

Usage
=====

You may find detailed documentation in the "docs" directory.

